@@ -41,6 +41,12 @@
 #include "hostap.h"
 #include "hostap_crypt.h"
 
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,14))
+#error Host AP driver was added into Linux 2.6.14.
+#error The version used in the kernel tree should be used instead of this
+#error external release which is only maintained for old kernel versions.
+#endif
+
 MODULE_AUTHOR("Jouni Malinen");
 MODULE_DESCRIPTION("Host AP common routines");
 MODULE_LICENSE("GPL");
